==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DThisRef.h <==
// public class soot.dava.internal.javaRep.DThisRef

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a101fb0afa50e2c8 soot_dava_internal_javaRep_DThisRef
// @dep_class 2d0601438aff315f soot_jimple_ThisRef

// header file dependencies
// @dep_header soot_jimple_ThisRef

#include "soot/jimple/ThisRef.h"

#ifndef _JC_soot_dava_internal_javaRep_DThisRef_H_
#define _JC_soot_dava_internal_javaRep_DThisRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_RefType$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DThisRef$sub_refs	_jc_soot_dava_internal_javaRep_DThisRef$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DThisRef$sub_nonrefs	_jc_soot_dava_internal_javaRep_DThisRef$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DThisRef$refs	_jc_soot_dava_internal_javaRep_DThisRef$refs;
typedef struct _jc_soot_dava_internal_javaRep_DThisRef$nonrefs	_jc_soot_dava_internal_javaRep_DThisRef$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DThisRef$object	_jc_soot_dava_internal_javaRep_DThisRef$object;

typedef const struct _jc_soot_dava_internal_javaRep_DThisRef$vmethods	_jc_soot_dava_internal_javaRep_DThisRef$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DThisRef$vtable	_jc_soot_dava_internal_javaRep_DThisRef$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DThisRef$vtype	_jc_soot_dava_internal_javaRep_DThisRef$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DThisRef$method$_init$b4480ebfa3c48018(_jc_env *, struct _jc_soot_dava_internal_javaRep_DThisRef$object *, struct _jc_soot_RefType$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DThisRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DThisRef$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DThisRef$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DThisRef$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DThisRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DThisRef$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DThisRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DThisRef$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DThisRef$object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DThisRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_ThisRef$vmethods	soot_jimple_ThisRef;
	_jc_soot_dava_internal_javaRep_DThisRef$vmethods	soot_dava_internal_javaRep_DThisRef;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DThisRef$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DThisRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DThisRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DThisRef$refs {
    _jc_soot_dava_internal_javaRep_DThisRef$sub_refs	soot_dava_internal_javaRep_DThisRef;
    _jc_soot_jimple_ThisRef$sub_refs	soot_jimple_ThisRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DThisRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DThisRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_ThisRef$sub_nonrefs	soot_jimple_ThisRef;
    _jc_soot_dava_internal_javaRep_DThisRef$sub_nonrefs	soot_dava_internal_javaRep_DThisRef;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DThisRef$object {
	_jc_soot_dava_internal_javaRep_DThisRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DThisRef$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DThisRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DThisRef$vtype _jc_soot_dava_internal_javaRep_DThisRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DThisRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DThisRef$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DThisRef_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DThisRef.h <==
// public class soot.dava.internal.javaRep.DThisRef

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a101fb0afa50e2c8 soot_dava_internal_javaRep_DThisRef
// @dep_class 2d0601438aff315f soot_jimple_ThisRef

// header file dependencies
// @dep_header soot_jimple_ThisRef

#include "soot/jimple/ThisRef.h"

#ifndef _JC_soot_dava_internal_javaRep_DThisRef_H_
#define _JC_soot_dava_internal_javaRep_DThisRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_RefType$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DThisRef$sub_refs	_jc_soot_dava_internal_javaRep_DThisRef$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DThisRef$sub_nonrefs	_jc_soot_dava_internal_javaRep_DThisRef$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DThisRef$refs	_jc_soot_dava_internal_javaRep_DThisRef$refs;
typedef struct _jc_soot_dava_internal_javaRep_DThisRef$nonrefs	_jc_soot_dava_internal_javaRep_DThisRef$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DThisRef$object	_jc_soot_dava_internal_javaRep_DThisRef$object;

typedef const struct _jc_soot_dava_internal_javaRep_DThisRef$vmethods	_jc_soot_dava_internal_javaRep_DThisRef$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DThisRef$vtable	_jc_soot_dava_internal_javaRep_DThisRef$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DThisRef$vtype	_jc_soot_dava_internal_javaRep_DThisRef$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DThisRef$method$_init$b4480ebfa3c48018(_jc_env *, struct _jc_soot_dava_internal_javaRep_DThisRef$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DThisRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DThisRef$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DThisRef$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DThisRef$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DThisRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DThisRef$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DThisRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DThisRef$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DThisRef$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DThisRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_ThisRef$vmethods	soot_jimple_ThisRef;
	_jc_soot_dava_internal_javaRep_DThisRef$vmethods	soot_dava_internal_javaRep_DThisRef;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DThisRef$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DThisRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DThisRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DThisRef$refs {
    _jc_soot_dava_internal_javaRep_DThisRef$sub_refs	soot_dava_internal_javaRep_DThisRef;
    _jc_soot_jimple_ThisRef$sub_refs	soot_jimple_ThisRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DThisRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DThisRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_ThisRef$sub_nonrefs	soot_jimple_ThisRef;
    _jc_soot_dava_internal_javaRep_DThisRef$sub_nonrefs	soot_dava_internal_javaRep_DThisRef;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DThisRef$object {
	_jc_soot_dava_internal_javaRep_DThisRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DThisRef$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DThisRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DThisRef$vtype _jc_soot_dava_internal_javaRep_DThisRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DThisRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DThisRef$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DThisRef_H_ */
